@@ -14,6 +14,7 @@ xfce_backdrop_image_style_get_type (void)
 	static GType type = 0;
 	if (type == 0) {
 	static const GEnumValue values[] = {
+	{ XFCE_BACKDROP_IMAGE_INVALID, "XFCE_BACKDROP_IMAGE_INVALID", "invalid" },
 	{ XFCE_BACKDROP_IMAGE_NONE, "XFCE_BACKDROP_IMAGE_NONE", "none" },
 	{ XFCE_BACKDROP_IMAGE_CENTERED, "XFCE_BACKDROP_IMAGE_CENTERED", "centered" },
 	{ XFCE_BACKDROP_IMAGE_TILED, "XFCE_BACKDROP_IMAGE_TILED", "tiled" },
@@ -33,6 +34,7 @@ xfce_backdrop_color_style_get_type (void)
 	static GType type = 0;
 	if (type == 0) {
 	static const GEnumValue values[] = {
+	{ XFCE_BACKDROP_COLOR_INVALID, "XFCE_BACKDROP_COLOR_INVALID", "invalid" },
 	{ XFCE_BACKDROP_COLOR_SOLID, "XFCE_BACKDROP_COLOR_SOLID", "solid" },
 	{ XFCE_BACKDROP_COLOR_HORIZ_GRADIENT, "XFCE_BACKDROP_COLOR_HORIZ_GRADIENT", "horiz-gradient" },
 	{ XFCE_BACKDROP_COLOR_VERT_GRADIENT, "XFCE_BACKDROP_COLOR_VERT_GRADIENT", "vert-gradient" },
@@ -43,6 +45,26 @@ xfce_backdrop_color_style_get_type (void)
   }
 	return type;
 }
+GType
+xfce_backdrop_cycle_period_get_type (void)
+{
+	static GType type = 0;
+	if (type == 0) {
+	static const GEnumValue values[] = {
+	{ XFCE_BACKDROP_PERIOD_INVALID, "XFCE_BACKDROP_PERIOD_INVALID", "invalid" },
+	{ XFCE_BACKDROP_PERIOD_SECONDS, "XFCE_BACKDROP_PERIOD_SECONDS", "seconds" },
+	{ XFCE_BACKDROP_PERIOD_MINUES, "XFCE_BACKDROP_PERIOD_MINUES", "minues" },
+	{ XFCE_BACKDROP_PERIOD_HOURS, "XFCE_BACKDROP_PERIOD_HOURS", "hours" },
+	{ XFCE_BACKDROP_PERIOD_STARTUP, "XFCE_BACKDROP_PERIOD_STARTUP", "startup" },
+	{ XFCE_BACKDROP_PERIOD_HOURLY, "XFCE_BACKDROP_PERIOD_HOURLY", "hourly" },
+	{ XFCE_BACKDROP_PERIOD_DAILY, "XFCE_BACKDROP_PERIOD_DAILY", "daily" },
+	{ XFCE_BACKDROP_PERIOD_CHRONOLOGICAL, "XFCE_BACKDROP_PERIOD_CHRONOLOGICAL", "chronological" },
+	{ 0, NULL, NULL }
+	};
+	type = g_enum_register_static ("XfceBackdropCyclePeriod", values);
+  }
+	return type;
+}
 
 /* enumerations from "xfce-desktop.h" */
 GType
